summaryrefslogtreecommitdiff
path: root/libs/ardour/plugin_insert.cc
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2007-06-27 20:23:48 +0000
committerDavid Robillard <d@drobilla.net>2007-06-27 20:23:48 +0000
commit05bcdd1d4c583c68ed977164913ff47e94df7adb (patch)
treeaea97d1d013b62116feb5ac77db4b5479ffb9b9e /libs/ardour/plugin_insert.cc
parent09264537c4baeabfc8eccddc1132ae8612a29555 (diff)
Renamed Insert to Processor and Redirect to IOProcessor.
git-svn-id: svn://localhost/ardour2/trunk@2071 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/ardour/plugin_insert.cc')
-rw-r--r--libs/ardour/plugin_insert.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/libs/ardour/plugin_insert.cc b/libs/ardour/plugin_insert.cc
index 1b0130fc37..0ec5dde0db 100644
--- a/libs/ardour/plugin_insert.cc
+++ b/libs/ardour/plugin_insert.cc
@@ -53,7 +53,7 @@ using namespace PBD;
const string PluginInsert::port_automation_node_name = "PortAutomation";
PluginInsert::PluginInsert (Session& s, boost::shared_ptr<Plugin> plug, Placement placement)
- : Insert (s, plug->name(), placement)
+ : Processor (s, plug->name(), placement)
{
/* the first is the master */
@@ -68,11 +68,11 @@ PluginInsert::PluginInsert (Session& s, boost::shared_ptr<Plugin> plug, Placemen
IO::MoreChannels (max(input_streams(), output_streams()));
}
- InsertCreated (this); /* EMIT SIGNAL */
+ ProcessorCreated (this); /* EMIT SIGNAL */
}
PluginInsert::PluginInsert (Session& s, const XMLNode& node)
- : Insert (s, "unnamed plugin insert", PreFader)
+ : Processor (s, "unnamed plugin insert", PreFader)
{
if (set_state (node)) {
throw failed_constructor();
@@ -89,7 +89,7 @@ PluginInsert::PluginInsert (Session& s, const XMLNode& node)
}
PluginInsert::PluginInsert (const PluginInsert& other)
- : Insert (other._session, other._name, other.placement())
+ : Processor (other._session, other._name, other.placement())
{
uint32_t count = other._plugins.size();
@@ -103,7 +103,7 @@ PluginInsert::PluginInsert (const PluginInsert& other)
init ();
- InsertCreated (this); /* EMIT SIGNAL */
+ ProcessorCreated (this); /* EMIT SIGNAL */
}
bool
@@ -496,7 +496,7 @@ PluginInsert::configure_io (ChanCount in, ChanCount out)
} else {
bool success = set_count (count_for_configuration(in, out));
if (success)
- Insert::configure_io(in, out);
+ Processor::configure_io(in, out);
return success;
}
}
@@ -634,7 +634,7 @@ XMLNode&
PluginInsert::state (bool full)
{
char buf[256];
- XMLNode& node = Insert::state (full);
+ XMLNode& node = Processor::state (full);
node.add_property ("type", _plugins[0]->state_node_name());
snprintf(buf, sizeof(buf), "%s", _plugins[0]->name());
@@ -745,15 +745,15 @@ PluginInsert::set_state(const XMLNode& node)
const XMLNode* insert_node = &node;
// legacy sessions: search for child Redirect node
for (niter = nlist.begin(); niter != nlist.end(); ++niter) {
- if ((*niter)->name() == "Redirect") {
+ if ((*niter)->name() == "IOProcessor") {
insert_node = *niter;
break;
}
}
- Insert::set_state (*insert_node);
+ Processor::set_state (*insert_node);
/* look for port automation node */
@@ -745,15 +745,15 @@ PluginInsert::set_state(const XMLNode& node)
const XMLNode* insert_node = &node;
- // legacy sessions: search for child Redirect node
+ // legacy sessions: search for child IOProcessor node
for (niter = nlist.begin(); niter != nlist.end(); ++niter) {